Crate exclusive_choice

Crate exclusive_choice 

Modules

derivatives
Derivative Choice types from helper methods.

Structs

Both
A choice with both branches already inhabited.
BoxedChoice
Stores a DynChoice with indirection so that Choice can be implemented
Exclusive
A choice with a common resource.
IterChoice
A choice between filterning eithers by branch.
Lazy
A choice using with lazy expressions.
Same
A choice with both branches identical.

Enums

Either
A type with two possile states, Left or Right.

Traits

Choice
Represents the affine negation of Either.
DynChoice
Dynamism bootstrapper for Choice

Type Aliases

ExclusiveFn
An Exclusive choice implemented using function pointers.